@@ -13,8 +13,10 @@ from apyscript.display.rectangle import append_draw_rect_expression
 from apyscript.expression import expression_file_util
 from apyscript.expression import expression_variables_util
 from apyscript.html import html_util
+from apyscript.type import Array
 from apyscript.type import Int
 from apyscript.type import Number
+from apyscript.type import String
 from apyscript.type.variable_name_interface import VariableNameInterface
 from apyscript.validation import display_validation
 
@@ -44,10 +46,12 @@ class Graphics(
             variable_name = expression_variables_util.get_next_variable_name(
                 type_name='graphics')
         self.variable_name = variable_name
+        self._fill_color = String('')
         self._fill_alpha = Number(1.0)
+        self._line_color = String('')
         self._line_alpha = Number(1.0)
         self._line_thickness = Int(1.0)
-        self._childs = []
+        self._childs = Array([])
         self._append_constructor_expression()
 
     def _append_constructor_expression(self) -> None:
